::mods_hookBaseClass("items/shields/shield", function(o) {
	while(!("applyShieldDamage" in o)) o = o[o.SuperName];
	o.applyShieldDamage = function( _damage, _playHitSound = true ) {
		if (this.m.Condition == 0)
		{
			return;
		}

		if (this.getContainer().getActor().getCurrentProperties().IsSpecializedInShields)
		{
			_damage = this.Math.max(1, this.Math.ceil(_damage * 0.5));
		}

		local Condition = this.m.Condition;
		Condition = this.Math.maxf(0.0, this.m.Condition - _damage);

		if (Condition == 0)
		{
			if (this.m.SoundOnDestroyed.len() != 0)
			{
				this.Sound.play(this.m.SoundOnDestroyed[this.Math.rand(0, this.m.SoundOnDestroyed.len() - 1)], this.Const.Sound.Volume.Skill, this.getContainer().getActor().getPos());
			}

			if (this.m.ShieldDecal.len() > 0)
			{
				local ourTile = this.getContainer().getActor().getTile();
				local candidates = [];

				for( local i = 0; i < this.Const.Direction.COUNT; i = ++i )
				{
					if (!ourTile.hasNextTile(i))
					{
					}
					else
					{
						local tile = ourTile.getNextTile(i);

						if (tile.IsEmpty && !tile.Properties.has("IsItemSpawned") && !tile.IsCorpseSpawned && tile.Level <= ourTile.Level + 1)
						{
							candidates.push(tile);
						}
					}
				}

				if (candidates.len() != 0)
				{
					local tileToSpawnAt = candidates[this.Math.rand(0, candidates.len() - 1)];
					tileToSpawnAt.spawnDetail(this.m.ShieldDecal);
					tileToSpawnAt.Properties.add("IsItemSpawned");
					tileToSpawnAt.Properties.add("IsShieldItemSpawned");
				}
				else if (!ourTile.Properties.has("IsItemSpawned") && !ourTile.IsCorpseSpawned)
				{
					ourTile.spawnDetail(this.m.ShieldDecal);
					ourTile.Properties.add("IsItemSpawned");
					ourTile.Properties.add("IsShieldItemSpawned");
				}
			}

			local actor = this.getContainer().getActor();
			this.m.Container.unequip(this);
			this.m.Condition = Condition;
			// logDebug("[DEBUG] Salvage Named Items : " + this.getName());
			if (this.isItemType(this.Const.Items.ItemType.Legendary) || this.isItemType(this.Const.Items.ItemType.Named)) this.drop(actor.getTile());
		}
		else
		{
			this.m.Condition = Condition;

			if (_playHitSound && this.m.SoundOnHit.len() != 0)
			{
				this.Sound.play(this.m.SoundOnHit[this.Math.rand(0, this.m.SoundOnHit.len() - 1)], this.Const.Sound.Volume.Skill, this.getContainer().getActor().getPos());
				this.Sound.play(this.m.SoundOnDestroyed[this.Math.rand(0, this.m.SoundOnDestroyed.len() - 1)], this.Const.Sound.Volume.Skill * 0.33, this.getContainer().getActor().getPos());
			}

			if (this.m.ShowOnCharacter)
			{
				local app = this.getContainer().getAppearance();

				if (this.m.Condition == 0)
				{
					app.Shield = "";
				}
				else if (this.m.Condition / (this.m.ConditionMax * 1.0) <= this.Const.Combat.ShowDamagedShieldThreshold)
				{
					app.Shield = this.m.SpriteDamaged;
				}
				else
				{
					app.Shield = this.m.Sprite;
				}

				this.getContainer().updateAppearance();
			}
		}
	}
});

::mods_hookBaseClass("items/weapons/weapon", function(o) {
	while(!("lowerCondition" in o)) o = o[o.SuperName];
	o.lowerCondition = function( _value = this.Const.Combat.WeaponDurabilityLossOnHit ) {
		local actor = this.getContainer().getActor();
		this.m.Condition = this.Math.maxf(0.0, this.m.Condition - _value);

		if (this.m.Condition == 0 && !actor.isHiddenToPlayer())
		{
			this.Tactical.EventLog.log(this.Const.UI.getColorizedEntityName(actor) + "\'s " + this.getName() + " has broken!");
			this.Tactical.spawnIconEffect("status_effect_36", actor.getTile(), this.Const.Tactical.Settings.SkillIconOffsetX, this.Const.Tactical.Settings.SkillIconOffsetY, this.Const.Tactical.Settings.SkillIconScale, this.Const.Tactical.Settings.SkillIconFadeInDuration, this.Const.Tactical.Settings.SkillIconStayDuration, this.Const.Tactical.Settings.SkillIconFadeOutDuration, this.Const.Tactical.Settings.SkillIconMovement);
			this.Sound.play(this.m.BreakingSound, 1.0, actor.getPos());
			// logDebug("[DEBUG] Salvage Named Items : " + this.getName());
			if (this.isItemType(this.Const.Items.ItemType.Legendary) || this.isItemType(this.Const.Items.ItemType.Named)) {
				this.Time.scheduleEvent(this.TimeUnit.Virtual, 300, this.drop, null);
			}
			else {
				this.Time.scheduleEvent(this.TimeUnit.Virtual, 300, this.onDelayedRemoveSelf, null);
			}
		}
	}
});